﻿/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import React, { useState } from "react"
import { View } from "react-native"
import { ProfileInformation } from "./ProfileSections/ProfileInformation"
import { ProfileLegal } from "./ProfileSections/ProfileLegal"
import { ProfilePrefs } from "./ProfileSections/ProfilePrefs"
import { ProfileSkills } from "./ProfileSections/ProfileSkills"
import { ProfileSubscription } from "./ProfileSections/ProfileSubscription"
import * as Linking from 'expo-linking' 
import { ProfileSection } from "./ProfileSections/ProfileSection"
import { ProfileSectionHeader } from "./ProfileSections/ProfileSectionHeader"
import { UserProfile } from "../../data/types"

interface ProfileSectionsProps {
    profile: UserProfile, 
}

export const ProfileSections: React.FC<ProfileSectionsProps> = ({profile}) => {
    const [infoCollapsed, toggleInfo] = useState<boolean>(true)
    const [skillsCollapsed, toggleSkills] = useState<boolean>(true)
    const [prefsCollapsed, togglePrefs] = useState<boolean>(true)
    const [subscriptionCollapsed, toggleSubscription] = useState<boolean>(true)
    const [legalCollapsed, toggleLegal] = useState<boolean>(true)

    const openInfo = () => {
        toggleInfo(!infoCollapsed)
        if (!skillsCollapsed) toggleSkills(true)
        if (!prefsCollapsed) togglePrefs(true)
        if (!subscriptionCollapsed) toggleSubscription(!subscriptionCollapsed)
        if (!legalCollapsed) toggleLegal(true)
    }

    const openSkills = () => {
        toggleSkills(!skillsCollapsed)
        if (!infoCollapsed) toggleInfo(true)
        if (!prefsCollapsed) togglePrefs(true)
        if (!subscriptionCollapsed) toggleSubscription(!subscriptionCollapsed)
        if (!legalCollapsed) toggleLegal(true)
    }

    const openPrefs = () => {
        togglePrefs(!prefsCollapsed)
        if (!infoCollapsed) toggleInfo(true)
        if (!skillsCollapsed) toggleSkills(true)
        if (!subscriptionCollapsed) toggleSubscription(!subscriptionCollapsed)
        if (!legalCollapsed) toggleLegal(true)
    }

    const openSubscription = () => {
        toggleSubscription(!subscriptionCollapsed)
        if (!infoCollapsed) toggleInfo(true)
        if (!skillsCollapsed) toggleSkills(true)
        if (!prefsCollapsed) togglePrefs(true)
        if (!legalCollapsed) toggleLegal(true)
    }

    const openLegal = () => {
        toggleLegal(!legalCollapsed)
        if (!infoCollapsed) toggleInfo(true)
        if (!subscriptionCollapsed) toggleSubscription(true)
        if (!skillsCollapsed) toggleSkills(true)
        if (!prefsCollapsed) togglePrefs(true)
    }

    const openFeedback = () => {
        Linking.openURL('mailto:dev@clicknpush.ca')
    }

    return (
        <View>
            <ProfileInformation 
                openInfo={openInfo} 
                infoCollapsed={infoCollapsed} 
                email={profile?.email} 
                username={profile?.username} />
            {/* <ProfileSkills openSkills={openSkills} skillsCollapsed={skillsCollapsed} /> */}
            <ProfilePrefs openPrefs={openPrefs} showTips={profile?.show_tips} prefsCollapsed={prefsCollapsed} />
            <ProfileSubscription openSubscription={openSubscription} subscriptionCollapsed={subscriptionCollapsed} />
            <ProfileLegal openLegal={openLegal} legalCollapsed={legalCollapsed} />
            <ProfileSectionHeader isCollapsed={true} collapseToggleMethod={openFeedback} title="Provide feedback"/>
        </View>
    )
}