﻿/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import React, { useEffect, useState } from "react"
import { Alert, Button, Switch, Text, TouchableOpacity, View } from "react-native"
import Collapsible from "react-native-collapsible"
import { useToggleTips } from "../../../data/profile/hooks"
import { GlobalStyles } from "../../../utils/GlobalUtils"
import { Separator } from "../../Separator"
import { ProfileSectionStyles } from "../Styles/ProfileSections.styles"
import { ProfileSection } from "./ProfileSection"
import { ProfileSectionHeader } from "./ProfileSectionHeader"

interface PrefsInformationProps {
    openPrefs: () => void
    prefsCollapsed: boolean
    showTips: boolean
}

export const ProfilePrefs: React.FC<PrefsInformationProps> = ({openPrefs, prefsCollapsed, showTips}) => {    
    const [localTipsEnabled, toggleLocalTips] = useState<boolean>(false)
    const toggleTips = useToggleTips()

    useEffect(() => {
        const changeTipsStateOnToggle = () => {
            toggleLocalTips(showTips)
        }
        changeTipsStateOnToggle()
    }, [showTips])

    useEffect(() => {
        if (toggleTips.isError) {
            Alert.alert("Error", "There was an error toggling tips. Please try again.",
            [{style: "cancel"}])
        }
    }, [toggleTips.status])

    const tryToggleTips = async () => {
        toggleLocalTips(!showTips)
        await toggleTips.mutateAsync();
    }

    return (
        <ProfileSection isCollapsed={prefsCollapsed} collapseToggleMethod={openPrefs} title="Preferences">
            <View style={GlobalStyles.itemRowContainer}>
                <Text>Startup tips:</Text>
                <Switch value={localTipsEnabled} onValueChange={async () => tryToggleTips()} />
            </View>
        </ProfileSection>
    )
}