import { action, makeObservable, observable } from "mobx";
import { Landmark } from "../types"

class LandmarkStore {
    selectedLandmarkId?: string = null
    updatedLandmark?: Landmark = null 
    newLandmark?: Landmark = null

    /**
     * Constructor. Uses mobx's [makeObservable]{@linkcode https://mobx.js.org/observable-state.html} to register actions and observable elements.
     */
     constructor() {
        makeObservable(this, {
            selectedLandmarkId: observable,
            updatedLandmark: observable,
            newLandmark: observable,
            setUpdatedLandmark: action,
            setSelectedLandmarkId: action,
            setNewLandmark: action,
        });
    }

    setSelectedLandmarkId(landmarkId: string) {
        this.selectedLandmarkId = landmarkId
    }

    setUpdatedLandmark(landmark: Landmark) {
        this.updatedLandmark = landmark
    }

    setNewLandmark(landmark: Landmark) {
        this.newLandmark = landmark
    }
}

export const landmarkStore = new LandmarkStore()