import { useMutation, useQuery, useQueryClient } from "react-query";
import { authStore } from "../../libs/auth/AuthStore";
import { makeAuthenticatedRequestAsync } from "../../libs/auth/core";
import { UserNotification } from "../types";

export const useMarkNotificationAsRead = () => {
    const queryClient = useQueryClient()
    return useMutation(async (notificationId: string) => {
    try {
        const response = await makeAuthenticatedRequestAsync({
            method: 'POST',
            url: `/api/user-profile/notifications/mark-read/${notificationId}/`,
        }, "Error marking notification as read.");   
        return response.data;
    } catch (error) {throw new Error;}
    }, {
        onSuccess: () => { queryClient.invalidateQueries('getNotifications')},  
        onError: () => queryClient.invalidateQueries('getNotifications'),  
    })
}

export const useDeleteNotification = () => {
    const queryClient = useQueryClient()
    return useMutation(async (notificationId: string) => { 
        try {
        const response = await makeAuthenticatedRequestAsync({
            method: 'DELETE',
            url: `/api/user-profile/notifications/delete/${notificationId}/`,
        }, "Error deleting notification.");   
        return response.data;
    } catch (error) {throw new Error;}
}, {
    onSuccess: () => { queryClient.invalidateQueries('getNotifications')},  
    onError: () => queryClient.invalidateQueries('getNotifications'),  
})}

export const useGetNotifications = () => {
    return useQuery<UserNotification[]>("getNotifications", async () => {
        if (authStore.userId) {
            try {
                const response = await makeAuthenticatedRequestAsync({
                    method: 'GET',
                    url: `/api/user-profile/notifications/${authStore.userId}/`,
                }, "Error fetching notifications.");   
                return response.data
            } catch (error) {throw new Error;}   
        }
    })
}