/**
 * Interface representing a landmark object
 */
 export interface Landmark {
    /**
     * The id of the landmark.
     */
    id?: string | null,
    /**
     * The rating of the landmark.
     */
    rating?: number | null,
    /**
     * The id of the user who created the landmark.
     */
    user?: string | null,
    /**
     * The x coordinate (or longitude) of the landmark's location.
     */
    longitude?: number | null,
    /**
     * The y coordinate (or latitude) of the landmark's location.
     */
    latitude?: number | null, 
    /**
     * The landmark's title.
     */
    title?: string | null,
    /**
     * The landmark's description.
     */
    description?: string | null,
    /**
     * User [comments]{@link LMComment} associated with this landmark.
     */
    comments?: LMComment[] | null,
    /**
     * [Photos]{@link LMPhoto} associated with this landmark.
     */
     photos?: LMPhoto[] | null,
    /**
     * An integer representing the type of this landmark.
     */
    landmark_type?: number | null, // for working with existing database schema, should be changed
    /**
     * A Date object representing when this landmark was created.
     */
    time?: Date | null,
}

export interface  LMPhoto {
    id: string
    landmark: string,
    image_b64: string
    height: number,
    width: number
}

/**
 * Interface representing a landmark's comment.
 */
 export interface LMComment {
    /**
     * The comment's id.
     */
    id: string,
    /**
     * The id of the user who posted the comment
     */
    poster: string,
    /**
     * The username of the user who posted the comment
     */
     poster_name: string,
    /**
     * The text content of the comment
     */
    content: string
    /**
     * The landmark id that this comment is associated with.
     */
    landmark: string
    /**
     * Timestamp of when the comment was posted.
     */
     timestamp?: Date
    /**
     * Whether or not the comment has been edited.
     */
     edited: boolean
}

export interface UserProfile {
    /**
     * The user's id
     */
    id?: string
    /**
     * The user's username
     */
    username?: string
    /**
     * The user's email
     */
    email?: string
    /**
     * The user's base64 encoded profile picture.
     */
    image_b64?: string
    /**
     * The user's preference for seeing tips.
     */
    show_tips?: boolean
}

export interface UserNotification {
    id: string
    user: string
    title: string
    data: string
    read: boolean
}

/**
 * String enum for type of registration validation request to send to server
 */
 type RegisterCredsValidationType = 'usernamevalidation' | 'emailvalidation';

 export interface RegisterCredsValues {
     email: string;
     username: string;
 }